Usage
guiDlgDoubleList(list1, list2, title = "Select", default1 = "", default2 = "",
multi = c(TRUE, TRUE), new = c(FALSE, FALSE), sort = c(TRUE, TRUE),
transfer = FALSE, parent = 0, GUI = getOption("guiWidgets"))Arguments
list1
the first list items.
list2
the second list items.
title
a title for this dialog box.
default1
selected items by default for the first list.
default2
selected items by default for the second list.
multi
do we allow multiple selection for first and second list.
new
do we allow to create new items for first and second list.
sort
do we sort first and second list.
transfer
the transfer mode allows to transfer items form one list to
the other.
parent
which window is the parent of this dialog box?
GUI
which GUI toolkit would we use?