Learn R Programming

svDialogs (version 0.9-43)

guiDlgVarSel: A select variable dialog box

Description

Present a list of variables of a given class and allow to choose one or several of them.

Usage

guiDlgVarSel(list, classes = NULL, title = "Select a variable", default = "",
    all.names = FALSE, multi = FALSE, new = FALSE, sort = TRUE, parent = 0,
    GUI = getOption("guiWidgets"))

Arguments

list
a list of variables.
classes
classes for the variables to search for.
title
a title of the dialog box.
default
the default selected item.
all.names
do we search for all names (including variables starting with '.')?
multi
do we allow multiple selection?
new
do we allow to create new variables?
sort
do we sort the list?
parent
which window is the parent of this dialog box?
GUI
which GUI toolkit do we use?

Value

  • A list with selected variables names.

concept

GUI API dialog boxes

See Also

guiDlgItemSel

Examples

Run this code
### TODO...

Run the code above in your browser using DataLab