Usage
guiDlgList(items, multi = FALSE, message = if (multi) "Select item(s):" else
"Select one item:", title = "Selection", default = 1, nsel = NULL,
new = FALSE, sort = FALSE, width = 50, parent = 0,
GUI = getOption("guiWidgets"))Arguments
multi
is it a multiple selection dialog box?
message
the message to display on top of the list.
title
the title of the dialog box.
default
the default selected item.
nsel
maximum number of selected items allowed.
new
do we allow to create new items?
width
the width of the dialog box.
parent
which window is the parent of this dialog box?
GUI
which GUI toolkit do we use for this dialog box?